@@ -23,7 +23,6 @@ from pyrone.version import PYRONE_VERSION
 from pyrone.models.config import get as get_config
 from pyrone.models import DBSession, Article, Tag, Comment
 from pyrone.lib import auth, lang
-from pyrone.lib.lang import supported_langs
 from pyrone.lib import cache
 
 log = logging.getLogger(__name__)
@@ -246,7 +245,7 @@ def get_public_tags_cloud(force_reload=False):
     value = cache.get_value('tags_cloud')
     if value is None or force_reload:
         dbsession = DBSession()
-        q = dbsession.query(func.count(Tag.id), Tag.tag).join(Article).filter(Article.is_draft is False).group_by(Tag.tag)
+        q = dbsession.query(func.count(Tag.id), Tag.tag).join(Article).filter(Article.is_draft==False).group_by(Tag.tag)
         items = list()
         counts = list()
         total = 0
@@ -279,7 +278,7 @@ def get_public_tags_cloud(force_reload=False):
     return value
 
 
-def get_pages_widget_links(lang_code, force_reload=False):
+def get_pages_widget_links(force_reload=False):
 
     value = cache.get_value('pages_links')
 
@@ -293,21 +292,21 @@ def get_pages_widget_links(lang_code, force_reload=False):
             line = line.strip()
             if len(line) == 0:
                 continue
-            # take first char - it will be delimiter
+            # take first char - it's a delimiter
             delim = line[0]
             components = line[1:].split(delim)
-            if len(components) != 3:
+            if len(components) != 2:
                 continue
-            lang, url, title = components
+            url, title = components
             if not url.startswith('http://') and not url.startswith('https://'):
                 continue
-            link = dict(lang=lang, url=url, title=title)
+            link = {'url': url, 'title': title}
             pages_links.append(link)
 
         value = pages_links
         cache.set_value('pages_links', value)
 
-    return [x for x in value if x['lang'] == lang_code]
+    return value
 
 
 def get_twitter_share_link_button(force_reload=False):
@@ -354,3 +353,7 @@ def get_not_approved_comments_count():
     dbsession = DBSession()
     cnt = dbsession.query(func.count(Comment.id)).filter(Comment.is_approved==False).scalar()
     return cnt
+
+def get_supported_langs_spec():
+    return lang.supported_langs_spec()
+
