@@ -4,16 +4,19 @@ Languages (i18n)
 """
 import logging
 
+from pyrone.models import config
+
 log = logging.getLogger(__name__)
 
-# DO NOT TRANSLATE!
-
-_languages = dict(en='english', ru=u'русский')
+# DO NOT LOCALIZE LINE BELOW!
+_languages = {
+    'en': u'english', 
+    'ru': u'русский'
+    }
 
 
-def supported_langs():
-    return ('en', 'ru')
-
+def supported_langs_spec():
+    return _languages
 
 def lang_title(lang_code):
     return _languages[lang_code]
@@ -24,9 +27,7 @@ def fallback_lang():
 
 
 def locale_negotiator(request):
-    lang = fallback_lang()
-    if 'ui_lang' in request.cookies:
-        lang = request.cookies['ui_lang']
+    lang = config.get('ui_lang')
     return lang
 
 lang = locale_negotiator
