@@ -127,7 +127,7 @@ function Pyrone_settings_saveSettings(url) {
 	              'admin_notifications_email', 'notifications_from_email', 'verification_msg_subject_tpl',
 	              'comment_answer_msg_subject_tpl', 'comment_answer_msg_body_tpl',
 	              'verification_msg_body_tpl', 'image_preview_width', 'google_analytics_id',
-                  'timezone', 'site_search_widget_code',
+                  'timezone', 'ui_lang', 'site_search_widget_code',
 	              'admin_notify_new_comment_subject_tpl', 'admin_notify_new_comment_body_tpl',
 	              'admin_notify_new_user_subject_tpl', 'admin_notify_new_user_body_tpl',
 	              'tw_consumer_key', 'tw_consumer_secret', 'social_twitter_share_link_via'];
