@@ -72,7 +72,7 @@ def save_settings_ajax(request):
               'admin_notify_new_comment_subject_tpl', 'admin_notify_new_comment_body_tpl',
               'admin_notify_new_user_subject_tpl', 'admin_notify_new_user_body_tpl',
               'verification_msg_body_tpl', 'image_preview_width', 'google_analytics_id',
-              'timezone', 'tw_consumer_key', 'tw_consumer_secret', 'social_twitter_share_link',
+              'timezone', 'ui_lang', 'tw_consumer_key', 'tw_consumer_secret', 'social_twitter_share_link',
               'social_twitter_share_link_show_count', 'social_twitter_share_link_via',
               'social_gplusone', 'site_search_widget_code')
 
@@ -866,5 +866,5 @@ def save_pages_widget_settings_ajax(request):
     widget_pages_pages_spec = request.POST['widget_pages_pages_spec']
     config.set('widget_pages_pages_spec', widget_pages_pages_spec)
     # force reload page links cache
-    h.get_pages_widget_links('en', True)
+    h.get_pages_widget_links(True)
     return c
