@@ -126,12 +126,12 @@ def tag_articles(request):
 
     c['prev_page'] = None
     if len(c['articles']) > page_size:
-        c['prev_page'] = route_url('blog_latest', request, _query=[('start', start_page+1), ('tag', tag)])
+        c['prev_page'] = route_url('blog_tag_articles', request, tag=tag, _query=[('start', start_page+1)])
         c['articles'].pop()
 
     c['next_page'] = None
     if start_page > 0:
-        c['next_page'] = route_url('blog_latest', request, _query=[('start', start_page-1), ('tag', tag)])
+        c['next_page'] = route_url('blog_tag_articles', request, tag=tag, _query=[('start', start_page-1)])
 
     c['page_title'] = _(u'Articles labeled with tag “%s”' % tag)
 
